<?php
/*
 * @copyright Copyright (c) 2024 AltumCode (https://altumcode.com/)
 *
 * This software is exclusively sold through https://altumcode.com/ by the AltumCode author.
 * Downloading this product from any other sources and running it without a proper license is illegal,
 *  except the official ones linked from https://altumcode.com/.
 */

namespace Altum\Controllers;

use Altum\Alerts;
use Altum\Meta;
use Altum\Router;
use Altum\Title;
use MaxMind\Db\Reader;

class ToolsCategories extends Controller {

    public function index() {
        redirect();
    }

    private function initiate() {
        if(!settings()->tools->categories_pages_is_enabled) {
            redirect();
        }

        if(string_starts_with('tools-categories/', \Altum\Router::$original_request)) {
            redirect(str_replace('_', '-', \Altum\Router::$method), true, 301);
        }

        /* Plans View */
        $view = new \Altum\View('partials/plans', (array) $this);
        $this->add_view_content('plans', $view->run());

        $tools_usage = (new \Altum\Models\Tools())->get_tools_usage();

        /* Popular tools View */
        $view = new \Altum\View('tools/popular_tools', (array) $this);
        $this->add_view_content('popular_tools', $view->run([
            'tools_usage' => $tools_usage,
            'tools' => require APP_PATH . 'includes/tools/tools.php',
            'category' => \Altum\Router::$method,
            'category_properties' => \Altum\Router::$data['tools_categories'][\Altum\Router::$method],
            'wrapper' => false,
        ]));

        /* Meta & title */
        Title::set(sprintf(l('tools_categories.title'), l('tools.' . \Altum\Router::$method )));
        Meta::set_description(l('tools.' . \Altum\Router::$method . '_help'));
        Meta::set_canonical_url();

        /* Prepare the view */
        $data = [
            'category' => \Altum\Router::$method,
            'category_properties' => \Altum\Router::$data['tools_categories'][\Altum\Router::$method],
            'tools_usage' => $tools_usage,
        ];

        $view = new \Altum\View('tools-categories/index', (array) $this);

        $this->add_view_content('content', $view->run($data));
    }

    public function checker_tools() {
        $this->initiate();
    }

    public function text_tools() {
        $this->initiate();
    }

    public function converter_tools() {
        $this->initiate();
    }

    public function generator_tools() {
        $this->initiate();
    }

    public function developer_tools() {
        $this->initiate();
    }

    public function image_manipulation_tools() {
        $this->initiate();
    }

    public function unit_converter_tools() {
        $this->initiate();
    }

    public function time_converter_tools() {
        $this->initiate();
    }

    public function data_converter_tools() {
        $this->initiate();
    }

    public function misc_tools() {
        $this->initiate();
    }

    public function length_converter_tools() {
        $this->initiate();
    }

    public function weight_converter_tools() {
        $this->initiate();
    }

    public function volume_converter_tools() {
        $this->initiate();
    }

    public function area_converter_tools() {
        $this->initiate();
    }

    public function force_converter_tools() {
        $this->initiate();
    }

}
